@@ -1,4 +1,4 @@
-/* $Id$
+/* $Id: gii.c,v 1.38 2005/09/03 18:16:24 soyt Exp $
 ******************************************************************************
 
    Graphics library for GGI. General Input Interface.
@@ -30,6 +30,8 @@
 */
 
 #include "config.h"
+
+#include <ggi/gg.h>
 #include <ggi/internal/gii.h>
 #include <ggi/internal/gii_debug.h>
 #include <ggi/internal/gii-dl.h>
@@ -54,7 +56,7 @@
 
 
 /* Static variables */
-static uint32	_gii_origin_count = GII_MAXSUBLIBS;
+static uint32_t	_gii_origin_count = GII_MAXSUBLIBS;
 
 
 /*
@@ -130,13 +132,13 @@ _giiEvQueueSetup(void)
 {
 	gii_ev_queue *qp;
 	
-	GIID2(GIIDPRINT_CORE("_giiEvQueueSetup() called\n"));
-
+	DPRINT2_CORE("_giiEvQueueSetup() called\n");
+	
 	qp = malloc(sizeof(gii_ev_queue));
 	if (qp == NULL) return NULL;
 	memset(qp, 0, sizeof(gii_ev_queue));
-
-	GIIDPRINT_CORE("_giiEvQueueSetup alloced %p\n", qp);
+	
+	DPRINT_CORE("_giiEvQueueSetup alloced %p\n", qp);
 	
 	return qp;
 }
@@ -147,15 +149,15 @@ static void _giiEvQueueDestroy(gii_input *inp)
 {
 	int queue;
 
-	GIIDPRINT_CORE("_giiEvQueueDestroy(%p) called\n", inp);
+	DPRINT_CORE("_giiEvQueueDestroy(%p) called\n", inp);
 	
 	if (inp->queue) {
-		GIIDPRINT_CORE("Destroying %p, %p\n",
-			       inp->queue, inp->queue->queues);
+		DPRINT_CORE("Destroying %p, %p\n",
+			    inp->queue, inp->queue->queues);
 		for (queue=0; queue < evLast; queue++) {
-			GIID2(GIIDPRINT_CORE(
+			DPRINT2_CORE(
 				"_giiEvQueueDestroy going %d, %p\n",
-				queue, inp->queue->queues[queue]));
+				queue, inp->queue->queues[queue]);
 			if (inp->queue->queues[queue]) {
 				free(inp->queue->queues[queue]);
 			}
@@ -169,7 +171,7 @@ static void _giiEvQueueDestroy(gii_input *inp)
 		inp->safequeue = NULL;
 	}
 
-	GIIDPRINT_CORE("_giiEvQueueDestroy done\n");
+	DPRINT_CORE("_giiEvQueueDestroy done\n");
 }
 
 /* Allocate the queue for that input. Individual queues are created on demand.
@@ -179,7 +181,7 @@ static int _giiEvQueueAllocate(gii_input *inp)
 	gii_ev_queue_set *qset;
 	int i;
 
-	GIIDPRINT_EVENTS("_giiEvQueueAllocate(%p) called\n", inp);
+	DPRINT_EVENTS("_giiEvQueueAllocate(%p) called\n", inp);
 
 	qset = malloc(sizeof(gii_ev_queue_set));
 	if (qset == NULL) return GGI_ENOMEM;
@@ -196,7 +198,7 @@ static int _giiEvQueueAllocate(gii_input *inp)
 
 	inp->queue = qset;
 
-	GIIDPRINT_EVENTS("Got queue_set: %p\n", inp->queue);
+	DPRINT_EVENTS("Got queue_set: %p\n", inp->queue);
 
 	return 0;
 }
@@ -269,7 +271,7 @@ _giiDeleteEvent(gii_ev_queue *qp)
 static inline void
 _giiGetEvent(gii_ev_queue *qp, gii_event *ev)
 {
-	uint8 size = qp->buf[qp->tail];
+	uint8_t size = qp->buf[qp->tail];
 
 	/* Pull event out of queue.. */
 	memcpy(ev, qp->buf + qp->tail, size);
@@ -294,9 +296,9 @@ _giiEvQueueRelease(gii_input *inp, gii_event *ev, gii_event_mask mask)
 	struct timeval t_min;
 	int queue;
 
-	GIIDPRINT_EVENTS("_giiEvQueueRelease(%p, %p, 0x%x) called\n",
-			 inp, ev, mask);
-
+	DPRINT_EVENTS("_giiEvQueueRelease(%p, %p, 0x%x) called\n",
+		      inp, ev, mask);
+	
 	if (_gii_threadsafe) ggLock(inp->queue->mutex);
 
 	evm = mask & inp->queue->seen;
@@ -318,13 +320,13 @@ _giiEvQueueRelease(gii_input *inp, gii_event *ev, gii_event_mask mask)
 	for (queue=0; queue < evLast; queue++) {
 		struct gii_ev_queue *qp_tmp;
 		
-		GIID2(GIIDPRINT_EVENTS("queue = %p, queue->queues = %p, "
-				       "queue->queues[queue] = %p\n",
-				       inp->queue, inp->queue->queues,
-				       inp->queue->queues[queue]));
+		DPRINT2_EVENTS("queue = %p, queue->queues = %p, "
+			       "queue->queues[queue] = %p\n",
+			       inp->queue, inp->queue->queues,
+			       inp->queue->queues[queue]);
 		qp_tmp = inp->queue->queues[queue];
 		if (qp_tmp && qp_tmp->count && (evm & (1 << queue))) {
-			uint8 *e_tmp = (uint8 *)_giiPeekEvent(qp_tmp);
+			uint8_t *e_tmp = (uint8_t *)_giiPeekEvent(qp_tmp);
 			struct timeval t_tmp;
 
 			/* Assure aligned memory access. Some platforms
@@ -337,7 +339,7 @@ _giiEvQueueRelease(gii_input *inp, gii_event *ev, gii_event_mask mask)
 			if (t_tmp.tv_sec < t_min.tv_sec || 
 			    (t_tmp.tv_sec == t_min.tv_sec &&
                              t_tmp.tv_usec < t_min.tv_usec)) {
-				GIID2(GIIDPRINT_EVENTS("_giiEvQueueRelease: Plausible found.\n"));
+				DPRINT2_EVENTS("_giiEvQueueRelease: Plausible found.\n");
 				qp = qp_tmp;
 				t_min = t_tmp;
 			}
@@ -345,7 +347,7 @@ _giiEvQueueRelease(gii_input *inp, gii_event *ev, gii_event_mask mask)
 	}
 
 	/* Shouldn't happen.. */
-	LIBGII_ASSERT(qp != NULL, "_giiEvQueueRelease: Arrgghh!! Nothing plausible");
+	LIB_ASSERT(qp != NULL, "_giiEvQueueRelease: Arrgghh!! Nothing plausible");
 	if (qp == NULL) {
 		if (_gii_threadsafe) ggUnlock(inp->queue->mutex);
 		return 0;
@@ -359,9 +361,9 @@ _giiEvQueueRelease(gii_input *inp, gii_event *ev, gii_event_mask mask)
 
 	if (_gii_threadsafe) ggUnlock(inp->queue->mutex);
 
-	GIIDPRINT_EVENTS("Retrieved event type %d, size %d.\n", 
-			 ev->any.type, ev->size);
-
+	DPRINT_EVENTS("Retrieved event type %d, size %d.\n", 
+		      ev->any.type, ev->size);
+	
 	return ev->size;
 }
 
@@ -370,9 +372,9 @@ _giiEvQueueRelease(gii_input *inp, gii_event *ev, gii_event_mask mask)
 static void _giiSetQueue(struct gii_input *inp, struct gii_input *set)
 {
 	struct gii_input *curr = inp;
-
-	GIIDPRINT_EVENTS("_giiSetQueue(%p, %p) called\n", inp, set);
-
+	
+	DPRINT_EVENTS("_giiSetQueue(%p, %p) called\n", inp, set);
+	
 	do {
 		curr->queue     = set->queue;
 		curr->safequeue = set->safequeue;
@@ -413,8 +415,8 @@ int _giiStdSendDevInfo(gii_input *inp, gii_cmddata_getdevinfo *data)
 	int size = sizeof(gii_cmd_nodata_event) +
 			sizeof(gii_cmddata_getdevinfo);
 
-	GIIDPRINT_EVENTS("_giiStdSendDevInfo(%p, %p\n)", inp, data);
-
+	DPRINT_EVENTS("_giiStdSendDevInfo(%p, %p\n)", inp, data);
+	
 	_giiEventBlank(&ev, size);
 
 	ev.any.size	= size;
@@ -440,9 +442,9 @@ int _giiStdSendValEvent(gii_input *inp, gii_cmddata_getvalinfo *vi,
 	gii_event ev;
 	size_t size;
 
-	GIIDPRINT_EVENTS("_giiStdSendValEvent(%p, %p, %i, %i) called\n",
-			inp, VI, val, maxval);
-
+	DPRINT_EVENTS("_giiStdSendValEvent(%p, %p, %i, %i) called\n",
+		      inp, VI, val, maxval);
+	
 	if (val >= maxval) return GGI_EARGINVAL;
 
 	size = sizeof(gii_cmd_nodata_event) +
@@ -474,14 +476,14 @@ int _giiEvQueueAdd(gii_input *inp, gii_event *ev)
 	struct gii_input *curr = inp;
 	int ret;
 
-	GIIDPRINT_EVENTS("_giiEvQueueAdd(%p, %p) called\n", inp, ev);
-
+	DPRINT_EVENTS("_giiEvQueueAdd(%p, %p) called\n", inp, ev);
+	
 	if (! curr) return GGI_EARGINVAL;
 
 	/* Check if type is in range */
 	if (ev->any.type >= evLast) {
-		GIIDPRINT_EVENTS("_giiEvQueueAdd: bad type: 0x%x\n",
-				 ev->any.type );
+		DPRINT_EVENTS("_giiEvQueueAdd: bad type: 0x%x\n",
+			      ev->any.type );
 		return 0;
 	}
 
@@ -508,9 +510,9 @@ int _giiEvQueueAdd(gii_input *inp, gii_event *ev)
 		inp->queue->queues[ev->any.type] = qp;
 	}
 
-	GIIDPRINT_EVENTS("Adding event type %d, size %d at pos %d\n",
-			 ev->any.type, ev->size, qp->count);
-
+	DPRINT_EVENTS("Adding event type %d, size %d at pos %d\n",
+		      ev->any.type, ev->size, qp->count);
+	
 	ret = _giiAddEvent(qp, ev);
 	if (ret != 0) {
 		if (_gii_threadsafe) ggUnlock(inp->queue->mutex);
@@ -548,12 +550,12 @@ int _giiSafeAdd(struct gii_input *inp, gii_event *ev)
 	} else {
 		_giiAddEvent(inp->safequeue, ev);
 		inp->cache->havesafe = 1;
-		GIIDPRINT_EVENTS("_giiSafeAdd added event type: 0x%x, size: %d"
-				 " at: %p, %p\n",
-				 ev->any.type, ev->size, inp->safequeue->head,
-				 inp->safequeue->tail);
-	}		
-
+		DPRINT_EVENTS("_giiSafeAdd added event type: 0x%x, size: %d"
+			      " at: %p, %p\n",
+			      ev->any.type, ev->size, inp->safequeue->head,
+			      inp->safequeue->tail);
+	}
+	
 	ggUnlock(_gii_safe_lock);
 #ifdef HAVE_SIGPROCMASK
 	sigprocmask(SIG_SETMASK, &oldset, NULL);
@@ -573,16 +575,16 @@ int _giiSafeMove(struct gii_input *toinp, struct gii_input *frominp)
 	sigprocmask(SIG_BLOCK, &blockset, &oldset);
 #endif
 	ggLock(_gii_safe_lock);
-
-	GIIDPRINT_EVENTS("_giiSafeMove moving %d events\n",
-			 frominp->safequeue->count);
+	
+	DPRINT_EVENTS("_giiSafeMove moving %d events\n",
+		      frominp->safequeue->count);
 	while (frominp->safequeue->count) {
 		ret = _giiEvQueueAdd(toinp, _giiPeekEvent(frominp->safequeue));
 		if (ret != 0) {
 			goto safemove_finish;
 		}
 		_giiDeleteEvent(frominp->safequeue);
-		GIIDPRINT_EVENTS("_giiSafeMove stored event\n");
+		DPRINT_EVENTS("_giiSafeMove stored event\n");
 	}
 	frominp->cache->havesafe = 0;
 
@@ -625,7 +627,7 @@ struct gii_input *_giiInputAlloc(void)
 	}
 	ret->next = ret->prev = ret;	/* Ring structure ... self<->self */
 	ret->dlhand = NULL;
-	ret->devinfo = NULL;
+	GG_SLIST_INIT(&ret->devinfo);
 
 	ret->origin = _gii_origin_count++;
 
@@ -659,8 +661,8 @@ void _giiInputFree(struct gii_input *inp)
 	}
 
 	/* Free the associated device info structures */
-	while(inp->devinfo) {
-		_giiUnregisterDevice(inp,inp->devinfo->origin);
+	while(!GG_SLIST_EMPTY(&inp->devinfo)) {
+		_giiUnregisterDevice(inp, GG_SLIST_FIRST(&inp->devinfo)->origin);
 	}
 	if (inp->mutex) 
 		ggLockDestroy(inp->mutex);
@@ -678,8 +680,8 @@ _giiPollall(struct gii_input *inp, gii_event_mask mask, void *arg)
 	struct gii_input *curr = inp;
 	gii_event_mask retmask = 0;
 	
-	GIIDPRINT_EVENTS("_giiPollAll(%p, 0x%x, %p) called\n", inp, mask, arg);
-
+	DPRINT_EVENTS("_giiPollAll(%p, 0x%x, %p) called\n", inp, mask, arg);
+	
 	if (! curr || ! (curr->cache->eventmask & mask)) {
 		return 0;
 	}
@@ -702,13 +704,13 @@ _giiPollall(struct gii_input *inp, gii_event_mask mask, void *arg)
 /* Add a new device to an input source and
  * return its origin, or 0 on error.
  */
-uint32 _giiRegisterDevice(gii_input *inp,
-			  gii_cmddata_getdevinfo  *dev,
-			  gii_cmddata_getvalinfo  *val) {
+uint32_t _giiRegisterDevice(gii_input *inp,
+			    gii_cmddata_getdevinfo  *dev,
+			    gii_cmddata_getvalinfo  *val) {
 	gii_deviceinfo * ret;
 
-	if(inp->devinfo)
-		if ((inp->devinfo->origin & GII_SUBLIBMASK) == GII_SUBLIBMASK)
+	if (!GG_SLIST_EMPTY(&inp->devinfo))
+		if ((GG_SLIST_FIRST(&inp->devinfo)->origin & GII_SUBLIBMASK) == GII_SUBLIBMASK)
 			/* 
 			   Too many devices registered.
 			   
@@ -730,14 +732,14 @@ uint32 _giiRegisterDevice(gii_input *inp,
 	ret->dev = dev;
 	ret->val = val;
 	
-	if(inp->devinfo == NULL)
+	if (GG_SLIST_EMPTY(&inp->devinfo)) {
 		/* Device count start as 1, to keep origin designate
 		   the whole input. */
 		ret->origin = inp->origin + 1;
-	else
-		ret->origin = inp->devinfo->origin + 1;
-	ret->next = inp->devinfo;
-	inp->devinfo = ret;
+	} else {
+		ret->origin = GG_SLIST_FIRST(&inp->devinfo)->origin + 1;
+	}
+	GG_SLIST_INSERT_HEAD(&inp->devinfo, ret, devlist);
 	
 	return ret->origin;
 }
@@ -749,27 +751,28 @@ uint32 _giiRegisterDevice(gii_input *inp,
   return GGI_OK, or GGI_ENOTFOUND if no device match the origin.
   
  */
-int _giiUnregisterDevice(gii_input *inp, uint32 origin) {
+int _giiUnregisterDevice(gii_input *inp, uint32_t origin) {
 
 	gii_deviceinfo *t, *curr;
 	
-	if(inp->devinfo == NULL) return GGI_ENOTFOUND;
+	if (GG_SLIST_EMPTY(&inp->devinfo)) return GGI_ENOTFOUND;
 	
-	if(inp->devinfo->origin == origin) {
-		t = inp->devinfo;
-		inp->devinfo = inp->devinfo->next;
+	t = GG_SLIST_FIRST(&inp->devinfo);
+	if (t->origin == origin) {
+		GG_SLIST_REMOVE_HEAD(&inp->devinfo, devlist);
 		free(t);
 		return GGI_OK;
 	}
-	curr = inp->devinfo;
-	while(curr->next) {
-		if(curr->next->origin == origin) {
-			t = curr->next;
-			curr->next = curr->next->next;
+
+	GG_SLIST_FOREACH(curr, &inp->devinfo, devlist) {
+		t = GG_SLIST_NEXT(curr, devlist);
+		if (t->origin == origin) {
+			GG_SLIST_NEXT(curr, devlist) =
+				GG_SLIST_NEXT(GG_SLIST_NEXT(curr, devlist),
+						devlist);
 			free(t);
 			return GGI_OK;
 		}
-		curr=curr->next;
 	}
 	return GGI_ENOTFOUND;
 }
@@ -781,51 +784,37 @@ int _giiUnregisterDevice(gii_input *inp, uint32 origin) {
 struct gii_input *giiOpen(const char *input,...)
 {
 	struct gii_input *ret = NULL;
+	struct gii_input *inp;
+	struct gg_target_iter match;
+	giifunc_inputinit *init;
 	va_list	drivers;
 	void *argptr;
-	char target[1024];
-	char *args;
 	int err;
-
+	
+	
 	if (input == NULL) {
 		input = getenv("GII_INPUT");
-		if (input == NULL) {
+		if (input == NULL)
 			return NULL;
-		}
 		argptr = NULL;
 	} else {
 		va_start(drivers,input);
 		argptr = va_arg(drivers,void *);
 		va_end(drivers);
 	}
-
-	while (1) {
-		struct gii_input *inp;
+	
+	match.input  = input;
+	match.config = _giiconfhandle;
+	ggConfigIterTarget(&match);
+	GG_ITER_FOREACH(&match) {
 		
-		input = ggParseTarget(input, target, 1024);
-
-		if (input == NULL) break;
-
-		if (*target == '\0') {
-			fprintf(stderr, "giiOpen: missing input descriptor\n");
-			break;
-		}
-
-		args = strchr(target, ':');
-
-		if (args != NULL) {
-			*args++ = '\0';
-		} else {
-			args = "";
-		}
-
-		GIIDPRINT_CORE("Allocating input structure\n");
+		DPRINT_CORE("Allocating input structure\n");
 		
 		inp = _giiInputAlloc();
 		if (inp == NULL) break;
-
-		GIIDPRINT_LIBS("giiOpen adding \"%s\", \"%s\", %p\n",
-			       target, args, argptr);
+		
+		DPRINT_LIBS("giiOpen adding \"%s\", \"%s\", %p\n",
+			    match.target, match.options, argptr);
 		
 		/* Start at next boundary.  This leaves space for up 
 		 * to 256 subsystems ...  I don't think we will 
@@ -833,49 +822,36 @@ struct gii_input *giiOpen(const char *input,...)
 		_gii_origin_count += GII_MAXSUBLIBS; 
 		_gii_origin_count &= GII_MAINMASK;
 		_gii_origin_count &= ~GII_EV_ORIGIN_SENDEVENT;
-
-		inp->dlhand = _giiLoadDL(target, NULL);
-		GIIDPRINT_LIBS("_giiLoadDL returned %p\n", inp->dlhand);
+		
+		inp->dlhand = _giiLoadDL(match.target);
+		DPRINT_LIBS("_giiLoadDL returned %p\n", inp->dlhand);
+		
 		if (inp->dlhand == NULL) {
 			_giiInputFree(inp);
-		} else {
-			giifunc_inputinit *init = (giifunc_inputinit *)inp->dlhand->init;
-			err = init(inp, args, argptr);
-			GIIDPRINT_LIBS("%d=dlh->init(%p,\"%s\",%p) - %s\n",
-				       err, inp, args, argptr, target);
-			if (err) {
-				_giiCloseDL(inp->dlhand);
-				free(inp->dlhand);
-				_giiInputFree(inp);
-			} else {
-				inp->dlhand->identifier = ret;
-				if (ret == NULL) {
-					ret = inp;
-				} else {
-					ret = giiJoinInputs(ret, inp);
-				}
-			}
+			continue;
 		}
 		
-		while (*input && isspace((int)*input)) input++;
-
-		if (*input == '\0') {
-			break;
+		init = (giifunc_inputinit *)inp->dlhand->init;
+		err = init(inp, match.options, argptr, match.target);
+		DPRINT_LIBS("%d=dlh->init(%p,\"%s\",%p,\"%s\") - %s\n",
+			    err, inp, match.options, argptr, match.target, match.target);
+		if (err) {
+			_giiCloseDL(inp->dlhand);
+			free(inp->dlhand);
+			_giiInputFree(inp);
+			continue;
 		}
-
-		if (*input != ':') {
-			fprintf(stderr,
-				"giiOpen: expecting ':' between targets\n");
-			return ret;
-		}
-
-		input++;  /* skip ':' */
+		inp->dlhand->identifier = ret;
+		if (ret == NULL)
+			ret = inp;
+		else 
+			ret = giiJoinInputs(ret, inp);
 	}
-
-	if (ret) {
+	GG_ITER_DONE(&match);
+	
+	if (ret)
 		_giiUpdateCache(ret);
-	}
-
+	
 	return ret;
 }
 
@@ -884,7 +860,7 @@ int giiClose(struct gii_input *inp)
 	struct gii_input *curr = inp;
 	int rc = -1;
 
-	GIIDPRINT_LIBS("giiClose(%p) called\n", inp);
+	DPRINT_LIBS("giiClose(%p) called\n", inp);
 
 	if (! curr) return GGI_EARGINVAL;
 
@@ -919,7 +895,7 @@ struct gii_input *giiJoinInputs(struct gii_input *inp, struct gii_input *inp2)
 	struct gii_input *curr;
 	struct timeval tv={ 0,0 };
 	 
-	GIIDPRINT_EVENTS("giiJoinInputs(%p, %p) called\n", inp, inp2);
+	DPRINT_EVENTS("giiJoinInputs(%p, %p) called\n", inp, inp2);
 
 	if (inp == NULL) {
 		if (inp2) _giiUpdateCache(inp2);
@@ -937,9 +913,9 @@ struct gii_input *giiJoinInputs(struct gii_input *inp, struct gii_input *inp2)
 	   primary queue. */
 	while (giiEventPoll(inp2, emAll, &tv)) {
 		gii_event ev;
-		GIIDPRINT_CORE("Fetching event from %p\n", inp2);
+		DPRINT_CORE("Fetching event from %p\n", inp2);
 		giiEventRead(inp2, &ev, emAll);
-		GIIDPRINT_CORE("Storing event in %p\n", inp);
+		DPRINT_CORE("Storing event in %p\n", inp);
 		_giiEvQueueAdd(inp, &ev);        /* Post it */
 	}
 	if (inp2->safequeue && inp2->safequeue->count) {
@@ -974,7 +950,7 @@ struct gii_input *giiJoinInputs(struct gii_input *inp, struct gii_input *inp2)
 
 
 int giiSplitInputs(struct gii_input *inp, struct gii_input **newhand,
-		   uint32 origin, uint32 flags)
+		   uint32_t origin, uint32_t flags)
 {
 	struct gii_input *idx;
 	gii_deviceinfo   *di;
@@ -1002,15 +978,16 @@ int giiSplitInputs(struct gii_input *inp, struct gii_input **newhand,
 	do {
 		/* walk the queue until the right origin is found. */
 
-		if ( (idx->origin&GII_MAINMASK) != (origin&GII_MAINMASK) ) 
+		if ( (idx->origin & GII_MAINMASK) != (origin & GII_MAINMASK) ) 
 			goto trynextone;
 
 		if (origin == idx->origin) 
 			goto haveit;
 
-		for (di=idx->devinfo;di;di=di->next)
-			if (di->origin==origin)
+		GG_SLIST_FOREACH(di, &idx->devinfo, devlist) {
+			if (di->origin == origin)
 				goto haveit;
+		}
 
 	trynextone:
 		idx = idx->next;
@@ -1164,7 +1141,7 @@ int giiSetEventMask(struct gii_input *inp, gii_event_mask evm)
 	int rc = -1;
 	int i;
 
-	GIIDPRINT_EVENTS("GIIseteventmask(%p, 0x%x) called\n", inp, evm);
+	DPRINT_EVENTS("GIIseteventmask(%p, 0x%x) called\n", inp, evm);
 
 	if (! curr) return GGI_EARGINVAL;
 
@@ -1205,9 +1182,9 @@ gii_event_mask giiGetEventMask(struct gii_input *inp)
 int giiEventSend(struct gii_input *inp, gii_event *event)
 {
 	struct gii_input *curr = inp;
-
-	LIBGII_APPASSERT(inp != NULL, "giiEventSend: inp is NULL");
-
+	
+	APP_ASSERT(inp != NULL, "giiEventSend: inp is NULL");
+	
 	_GII_ev_timestamp(event);
 
 	/* FIXME! We should allow this to be or-ed in */
@@ -1250,16 +1227,18 @@ void giiPanic(const char *format, ...)
 	exit(1);
 }
 
-static gii_deviceinfo *giiFindDeviceInfo(gii_input_t inp, uint32 origin)
+static gii_deviceinfo *giiFindDeviceInfo(gii_input_t inp, uint32_t origin)
 {
 	struct gii_input *curr = inp;
 	gii_deviceinfo   *di;
 
 	do {
 		if ( (curr->origin&GII_MAINMASK) == (origin&GII_MAINMASK) ) {
-			for(di=curr->devinfo;di;di=di->next)
+
+			GG_SLIST_FOREACH(di, &curr->devinfo, devlist) {
 				if (di->origin==origin)
 					return di;
+			}
 			break;	/* The queried device _must_ be in that queue. */
 		}
 		curr = curr->next;
@@ -1267,44 +1246,47 @@ static gii_deviceinfo *giiFindDeviceInfo(gii_input_t inp, uint32 origin)
 	return NULL;
 }
 
-int giiQueryDeviceInfo(gii_input_t inp, uint32 origin,
+int giiQueryDeviceInfo(gii_input_t inp, uint32_t origin,
 		       gii_cmddata_getdevinfo *info)
 {
 	gii_deviceinfo *di=giiFindDeviceInfo(inp,origin);
 	if (di) {
-		*info=*di->dev;return 0;
+		*info = *di->dev;
+		return 0;
 	}
 	return GGI_ENOMATCH;
 }
 
 static gii_deviceinfo *
-giiFindDeviceInfoByNumber(gii_input_t inp, uint32 number, uint32 *origin)
+giiFindDeviceInfoByNumber(gii_input_t inp, uint32_t number, uint32_t *origin)
 {
 	struct gii_input *curr = inp;
 	gii_deviceinfo   *di;
 
 	do {
-		for(di=curr->devinfo;di;di=di->next)
+		GG_SLIST_FOREACH(di, &curr->devinfo, devlist) {
 			if (number--==0) {
 				if (origin) *origin=di->origin;
 				return di;
 			}
+		}
 		curr = curr->next;
 	} while(curr != inp);	/* looped through once. */
 	return NULL;
 }
 
-int giiQueryDeviceInfoByNumber(gii_input_t inp, uint32 number, uint32 *origin,
+int giiQueryDeviceInfoByNumber(gii_input_t inp, uint32_t number, uint32_t *origin,
 			       gii_cmddata_getdevinfo *info)
 {
 	gii_deviceinfo *di=giiFindDeviceInfoByNumber(inp,number,origin);
 	if (di) {
-		*info=*di->dev;return 0;
+		*info = *di->dev;
+		return 0;
 	}
 	return GGI_ENOMATCH;
 }
 
-int giiQueryValInfo(gii_input_t inp, uint32 origin, uint32 valnumber,
+int giiQueryValInfo(gii_input_t inp, uint32_t origin, uint32_t valnumber,
 		    gii_cmddata_getvalinfo *info)
 {
 	gii_deviceinfo *di=giiFindDeviceInfo(inp,origin);
