@@ -27,6 +27,9 @@
 */
 
 #include "config.h"
+
+#include <ggi/gg.h>
+#include <ggi/internal/gg_replace.h>
 #include <ggi/internal/gii.h>
 #include <ggi/internal/gii_debug.h>
 
@@ -41,13 +44,13 @@
 
 
 /* Exported variables */
-uint32                _giiDebugState   = 0;
-int                   _giiDebugSync    = 0;
+uint32_t              _giiDebug  = 0;
+
 int                   _gii_threadsafe  = 0;
 void                 *_gii_global_lock = NULL;
 
 /* Global variables */
-void                 *_giiconfhandle	= NULL;
+gg_config            _giiconfhandle	= NULL;
 void                 *_gii_safe_lock	= NULL;
 void                 *_gii_event_lock	= NULL;
 
@@ -56,6 +59,8 @@ static int 	      _giiLibIsUp =0 ;
 static char           giiconfstub[512] = GIICONFDIR;
 static char          *giiconfdir = giiconfstub + GIITAGLEN;
 
+void _giiInitBuiltins(void);
+void _giiExitBuiltins(void);
 
 /* 
  * Returns the directory where global config files are kept
@@ -127,37 +132,33 @@ int giiInit(void)
 		fprintf(stderr,"LibGII: unable to allocate memory for config filename.\n");
 		goto out_destroy_global;
 	}
-#ifdef HAVE_SNPRINTF
 	snprintf(conffile, strlen(giiGetConfDir()) + strlen(GIICONFFILE) + 2,
 		"%s%c%s", giiGetConfDir(), CHAR_DIRDELIM, GIICONFFILE);
-#else
-	sprintf(conffile, "%s%c%s",
-		giiGetConfDir(), CHAR_DIRDELIM,	GIICONFFILE);
-#endif
-	err = ggLoadConfig(conffile, &_giiconfhandle);
-	if (err != GGI_OK) {
+	if(ggLoadConfig(conffile, &_giiconfhandle)) {
 		fprintf(stderr, "LibGII: fatal error - could not load %s\n",
 			conffile);
 		free(conffile);
 		goto out_destroy_global;
 	}
 	free(conffile);
-
-	str = getenv("GGI_DEBUGSYNC");
+	
+	str = getenv("GII_DEBUGSYNC");
 	if (str != NULL) {
-		_giiDebugSync = 1;
+		_giiDebug |= DEBUG_SYNC;
+	}
+	
+	str = getenv("GII_DEBUG");
+	if (str != NULL) {
+		_giiDebug |= atoi(str) & DEBUG_ALL;
+		DPRINT_CORE("%s Debugging=%d\n",
+			    DEBUG_ISSYNC ? "sync" : "async",
+			    _giiDebug);
 	}
 
-	str = getenv("GGI_DEBUG");
-	if (str != NULL) {
-		_giiDebugState = atoi(str);
-		GIIDPRINT_CORE("%s Debugging=%d\n",
-				_giiDebugSync ? "sync" : "async",
-				_giiDebugState);
-	}
+	_giiInitBuiltins();
 
 	_giiLibIsUp++;
-
+	
 	return 0;
 
   out_destroy_global:
@@ -174,24 +175,36 @@ int giiInit(void)
 
 int giiExit(void)
 {
-	GIIDPRINT_CORE("giiExit() called\n");
+	DPRINT_CORE("giiExit() called\n");
 	if (!_giiLibIsUp)
 		return GGI_ENOTALLOC;
-
+	
 	if (_giiLibIsUp > 1) {
 		_giiLibIsUp--;
 		return _giiLibIsUp;
 	}
+	
+	DPRINT_CORE("giiExit: really destroying.\n");
 
-	GIIDPRINT_CORE("giiExit: really destroying.\n");
+	_giiExitBuiltins();
 
 	ggFreeConfig(_giiconfhandle);
 	ggLockDestroy(_gii_global_lock);
 	ggLockDestroy(_gii_safe_lock);
 	ggLockDestroy(_gii_event_lock);
+
+	/* Set them back to initialization value.
+	 * Otherwise this leads to a memory corruption bug,
+	 * when gii is initialized again in the same application.
+	 */
+	_giiconfhandle = NULL;
+	_gii_global_lock = NULL;
+	_gii_safe_lock = NULL;
+	_gii_event_lock = NULL;
+
 	ggExit();
 	_giiLibIsUp=0;
-
-	GIIDPRINT_CORE("giiExit: done!\n");
+	
+	DPRINT_CORE("giiExit: done!\n");
 	return 0;
 }
