@@ -1,4 +1,4 @@
-/* $Id: input.c,v 1.13 2004/09/22 20:02:54 nsouch Exp $
+/* $Id: input.c,v 1.16 2005/08/04 12:43:27 cegger Exp $
 ******************************************************************************
 
    Input-KII: Input for KII
@@ -27,10 +27,11 @@
 #include <string.h>
 #include <stdlib.h>
 
+#include <ggi/gg.h>
 #include <ggi/input/kii.h>
 
 #define KIIGII_N 51
-static struct { kii_u32_t ksym; uint32 gsym; int len; } kiigii[KIIGII_N] =
+static struct { kii_u32_t ksym; uint32_t gsym; int len; } kiigii[KIIGII_N] =
 	{
 	  /*
 	   *    Translation table KII symbols to GII symbols...
@@ -92,7 +93,7 @@ static struct { kii_u32_t ksym; uint32 gsym; int len; } kiigii[KIIGII_N] =
 	};
 
 #define SYMLAB_N 2
-static struct { uint32 sym; uint32 label; int len; } symlab[SYMLAB_N] = 
+static struct { uint32_t sym; uint32_t label; int len; } symlab[SYMLAB_N] = 
 	{
 	  /*
 	   *    Translation table GII symbols to GII labels...
@@ -132,7 +133,7 @@ static gii_event_mask GII_kii_handle_key(gii_input *inp, gii_event *ge,
 	ge->any.size = sizeof(gii_key_event);
 	ge->any.origin = inp->origin;
 	
-	GIIDPRINT_LIBS("sym: 0x%.8x, code: 0x%.8x, effect: 0x%.4x, "
+	DPRINT_LIBS("sym: 0x%.8x, code: 0x%.8x, effect: 0x%.4x, "
 		"normal: 0x%.4x, locked: 0x%.4x, sticky: 0x%.4x\n",
 		ke->key.sym, ke->key.code, ke->key.effect,
 		ke->key.normal, ke->key.locked, ke->key.sticky);
@@ -275,7 +276,7 @@ static gii_event_mask GII_kii_poll(gii_input *inp, void *arg)
 		if (! FD_ISSET(kiiEventDeviceFD(KII_CTX(inp)), ((fd_set*)arg))) {
 
 			/* Nothing to read on the fd set */
-			GIIDPRINT_EVENTS("GII_kii_poll: dummy poll\n");
+			DPRINT_EVENTS("GII_kii_poll: dummy poll\n");
 			return emZero;
 		}
 	}
@@ -351,18 +352,20 @@ static int GII_kii_close(gii_input *inp)
 	free(KII_CTX(inp));
 	free(priv);
 
-	GIIDPRINT_MISC("kii: exit OK.\n");
+	DPRINT_MISC("kii: exit OK.\n");
 
 	return 0;
 }
 
 
-int GIIdlinit(gii_input *inp, const char *args, void *argptr)
+EXPORTFUNC int GIIdl_kii(gii_input *inp, const char *args, void *argptr);
+
+int GIIdl_kii(gii_input *inp, const char *args, void *argptr)
 {
 	kii_priv *priv;
 	gg_option options[KII_NUM_OPTS];
 
-	GIIDPRINT_MISC("kii starting. (args=%s,argptr=%p)\n",
+	DPRINT_MISC("kii starting. (args=%s,argptr=%p)\n",
 			args, argptr);
     
 	if ((priv = inp->priv = malloc(sizeof(kii_priv))) == NULL) {
@@ -378,7 +381,7 @@ int GIIdlinit(gii_input *inp, const char *args, void *argptr)
 	if (args) {
 		args = ggParseOptions((char*)args, options, KII_NUM_OPTS);
 		if (args == NULL) {
-			GIIDPRINT_LIBS("Error in arguments\n");
+			DPRINT_LIBS("Error in arguments\n");
 			free(KII_CTX(inp));
 			free(priv);
 			return GGI_EARGINVAL;
@@ -421,7 +424,7 @@ int GIIdlinit(gii_input *inp, const char *args, void *argptr)
 
 	send_devinfo(inp);
 
-	GIIDPRINT_MISC("kii fully up\n");
+	DPRINT_MISC("kii fully up\n");
 
 	return 0;
 }
