@@ -1,4 +1,4 @@
-/* $Id: input.c,v 1.16 2004/09/16 13:24:58 pekberg Exp $
+/* $Id$
 ******************************************************************************
 
    Linux evdev inputlib
@@ -28,8 +28,8 @@
 
 #include "config.h"
 #include "linux_evdev.h"
+#include <ggi/gg.h>
 #include <ggi/internal/gii.h>
-#include <ggi/internal/gii_target.h>
 
 #include <stdlib.h>
 #include <string.h>
@@ -37,14 +37,14 @@
 #include <fcntl.h>
 #include <unistd.h>
 
-#define SKIPWHITE(str)	while (isspace((int)*(str))) (str)++
+#define SKIPWHITE(str)	while (isspace((uint8_t)*(str))) (str)++
 
-static char *events[EV_MAX + 1] =
+static const char *events[EV_MAX + 1] =
     { "Reset", "Key", "Relative", "Absolute", NULL, NULL, NULL, NULL, NULL,
 	NULL, NULL, NULL, NULL, NULL,
 	NULL, NULL, NULL, "LED", "Sound", NULL, "Repeat"
 };
-static char *keys[KEY_MAX + 1] =
+static const char *keys[KEY_MAX + 1] =
     { "Reserved", "Esc", "1", "2", "3", "4", "5", "6", "7", "8", "9", "0",
 	"Minus", "Equal", "Backspace",
 	"Tab", "Q", "W", "E", "R", "T", "Y", "U", "I", "O", "P",
@@ -121,24 +121,24 @@ static char *keys[KEY_MAX + 1] =
 };
 
 #if 0	/* defined but not used */
-static char *absval[5] = { "Value", "Min  ", "Max  ", "Fuzz ", "Flat " };
+static const char *absval[5] = { "Value", "Min  ", "Max  ", "Fuzz ", "Flat " };
 #endif
-static char *relatives[REL_MAX + 1] =
+static const char *relatives[REL_MAX + 1] =
     { "X", "Y", "Z", NULL, NULL, NULL, "HWheel", "Dial", "Wheel" };
-static char *absolutes[ABS_MAX + 1] =
+static const char *absolutes[ABS_MAX + 1] =
     { "X", "Y", "Z", "Rx", "Ry", "Rz", "Throttle", "Rudder", 
       "Wheel", "Gas", "Brake", NULL, NULL, NULL, NULL, NULL,
       "Hat0X", "Hat0Y", "Hat1X", "Hat1Y", "Hat2X", "Hat2Y", "Hat3X", "Hat 3Y",
       "Pressure", "Distance", "XTilt", "YTilt"
 };
-static char *leds[LED_MAX + 1] =
+static const char *leds[LED_MAX + 1] =
     { "NumLock", "CapsLock", "ScrollLock", "Compose", "Kana", "Sleep",
 	"Suspend", "Mute"
 };
-static char *repeats[REP_MAX + 1] = { "Delay", "Period" };
-static char *sounds[SND_MAX + 1] = { "Bell", "Click" };
+static const char *repeats[REP_MAX + 1] = { "Delay", "Period" };
+static const char *sounds[SND_MAX + 1] = { "Bell", "Click" };
 
-static char **names[EV_MAX + 1] =
+static const char **names[EV_MAX + 1] =
 	{ events, keys, relatives, absolutes, NULL, NULL, NULL, NULL, 
 	  NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 
 	  NULL, leds, sounds, repeats
@@ -237,7 +237,7 @@ static void send_devinfo(gii_input * inp)
 	_giiEvQueueAdd(inp, &ev);
 }
 
-static void send_valinfo(gii_input * inp, uint32 n)
+static void send_valinfo(gii_input * inp, uint32_t n)
 {
 	gii_event ev;
 	gii_cmddata_getvalinfo *vinfo;
@@ -279,7 +279,7 @@ static int GIIsendevent(gii_input * inp, gii_event * ev)
 		    (gii_cmddata_getvalinfo *) ev->cmd.data;
 		if (vi->number == GII_VAL_QUERY_ALL) {
 			if (test_bit(3, priv->bit[0])) {
-				uint32 i;
+				uint32_t i;
 				for (i = 0; i < KEY_MAX; i++)
 					if (test_bit(i, priv->bit[3]))
 						send_valinfo(inp, i);
@@ -307,13 +307,16 @@ static int GIIclose(struct gii_input *inp)
 }
 
 
-int GIIdlinit(gii_input * inp, const char *args, void *argptr)
+EXPORTFUNC int GIIdl_linux_evdev(gii_input * inp,
+				const char *args, void *argptr);
+
+int GIIdl_linux_evdev(gii_input * inp, const char *args, void *argptr)
 {
 	const char *devname = "/dev/input/event0";
 	gii_levdev_priv *priv;
 	int fd;
 
-	GIIDPRINT_LIBS("Linux evdev starting.\n");
+	DPRINT_LIBS("Linux evdev starting.\n");
 
 	if (args && *args)
 		devname = args;
@@ -353,7 +356,7 @@ int GIIdlinit(gii_input * inp, const char *args, void *argptr)
 	init_devinfo(inp);
 	send_devinfo(inp);
 
-	GIIDPRINT_LIBS("Linux evdev up.\n");
+	DPRINT_LIBS("Linux evdev up.\n");
 
 	return 0;
 }
