@@ -1,4 +1,4 @@
-/* $Id: input.c,v 1.9 2004/09/16 13:24:58 pekberg Exp $
+/* $Id: input.c,v 1.15 2005/08/09 10:14:48 aldot Exp $
 ******************************************************************************
 
    Linux_kbd: input via linux MEDIUMRAW mode.
@@ -27,8 +27,8 @@
 */
 
 #include "config.h"
+#include <ggi/gg.h>
 #include <ggi/internal/gii.h>
-#include <ggi/internal/gii_target.h>
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -66,15 +66,15 @@ typedef struct keyboard_hook
 	int old_mode;
 	struct termios old_termios;
 	char old_kbled;
-	
-	uint8  keydown_buf[128];
-	uint32 keydown_sym[128];
-	uint32 keydown_label[128];
 
-	uint32  modifiers;
-	uint32  normalmod;
-	uint32  lockedmod;
-	uint32  lockedmod2;
+	uint8_t  keydown_buf[128];
+	uint32_t keydown_sym[128];
+	uint32_t keydown_label[128];
+
+	uint32_t  modifiers;
+	uint32_t  normalmod;
+	uint32_t  lockedmod;
+	uint32_t  lockedmod2;
 
 	unsigned char	accent;
 	struct kbdiacrs	accent_table;
@@ -107,7 +107,7 @@ static void sighandler(int unused)
 }
 
 static inline int
-GII_keyboard_init(gii_input *inp, char *filename)
+GII_keyboard_init(gii_input *inp, const char *filename)
 {
 	int fd;
 	struct termios tio;
@@ -115,7 +115,7 @@ GII_keyboard_init(gii_input *inp, char *filename)
 	void (*oldinhandler)(int);
 	void (*oldouthandler)(int);
 
-	GIIDPRINT_MISC("Linux-kbd: opening tty\n");
+	DPRINT_MISC("Linux-kbd: opening tty\n");
 
 	/* open the tty */
 	fd = open(filename, O_RDWR);
@@ -131,7 +131,7 @@ GII_keyboard_init(gii_input *inp, char *filename)
 		return GGI_ENOMEM;
 	}
 
-	GIIDPRINT_MISC("Linux-kbd: calling tcgetattr()\n");
+	DPRINT_MISC("Linux-kbd: calling tcgetattr()\n");
 
 	/* put tty into "straight through" mode.
 	 */
@@ -147,7 +147,7 @@ GII_keyboard_init(gii_input *inp, char *filename)
 	tio.c_cc[VMIN]  = 0;
 	tio.c_cc[VTIME] = 0;
 
-	GIIDPRINT_MISC("Linux-kbd: calling tcsetattr()\n");
+	DPRINT_MISC("Linux-kbd: calling tcsetattr()\n");
 
 	got_stopped = 0;
 	oldinhandler  = signal(SIGTTIN, sighandler);
@@ -171,7 +171,7 @@ GII_keyboard_init(gii_input *inp, char *filename)
 	 * is really "mostly raw", with the kernel just folding long
 	 * scancode sequences (e.g. E0 XX) onto single keycodes.
 	 */
-	GIIDPRINT_MISC("Linux-kbd: going to MEDIUMRAW mode\n");
+	DPRINT_MISC("Linux-kbd: going to MEDIUMRAW mode\n");
 	if (ioctl(fd, KDGKBMODE, &priv->old_mode) < 0) {
 		perror("Linux-kbd: couldn't get mode");
 		priv->old_mode = K_XLATE;
@@ -231,7 +231,7 @@ GII_keyboard_init(gii_input *inp, char *filename)
 	}
 	inp->priv = priv;
 
-	GIIDPRINT_MISC("Linux-kbd: init OK.\n");
+	DPRINT_MISC("Linux-kbd: init OK.\n");
 
 	return 0;
 }
@@ -254,7 +254,7 @@ GII_keyboard_flush_keys(gii_input *inp)
 
 		/* Send a key-release event */
 		_giiEventBlank(&ev, sizeof(gii_key_event));
-		
+
 		ev.any.type   = evKeyRelease;
 		ev.any.size   = sizeof(gii_key_event);
 		ev.any.origin = inp->origin;
@@ -264,11 +264,11 @@ GII_keyboard_flush_keys(gii_input *inp)
 		ev.key.label  = priv->keydown_label[code];
 		ev.key.modifiers = priv->modifiers;
 
-		GIIDPRINT_EVENTS("Linux-kbd: flushing key: button=0x%02x "
+		DPRINT_EVENTS("Linux-kbd: flushing key: button=0x%02x "
 			"modifiers=0x%02x sym=0x%04x label=0x%04x.\n",
-			ev.key.button, ev.key.modifiers, ev.key.sym, 
+			ev.key.button, ev.key.modifiers, ev.key.sym,
 			ev.key.label);
-		
+
 		_giiEvQueueAdd(inp, &ev);
 
 		rc |= emKeyRelease;
@@ -293,9 +293,9 @@ handle_accent(linkbd_priv *priv, int symval, gii_event *ev)
 
 	for (i = 0; i < priv->accent_table.kb_cnt; i++) {
 		if (priv->accent_table.kbdiacr[i].diacr == diacr &&
-		    priv->accent_table.kbdiacr[i].base 
+		    priv->accent_table.kbdiacr[i].base
 		    == ev->key.sym) {
-			ev->key.sym 
+			ev->key.sym
 				= priv->accent_table.kbdiacr[i].result;
 				break;
 		}
@@ -305,12 +305,11 @@ handle_accent(linkbd_priv *priv, int symval, gii_event *ev)
 	priv->accent = 0;
 }
 
-	
 static inline void
 handle_modifier(linkbd_priv *priv, gii_event *ev)
 {
-	uint32 mask;
-		
+	uint32_t mask, old_label;
+
 	/* Handle AltGr properly */
 	if (ev->key.label == GIIK_AltR) {
 		if (ev->key.sym == GIIK_VOID) {
@@ -320,6 +319,17 @@ handle_modifier(linkbd_priv *priv, gii_event *ev)
 	} else {
 		mask = 1 << (ev->key.label & GII_KM_MASK);
 	}
+	/* Handle CapsShift properly: shift keys undo CapsLock */
+	if ((ev->key.label == GIIK_ShiftL || ev->key.label == GIIK_ShiftR) &&
+	    ev->key.sym == GIIK_CapsLock) {
+		if (priv->lockedmod & GII_MOD_CAPS) {
+			old_label = ev->key.label;
+			ev->key.label = GIIK_CapsLock;
+			handle_modifier(priv, ev);
+			ev->key.label = old_label;
+		}
+		ev->key.sym = GIIK_Shift;
+	}
 
 	if (GII_KVAL(ev->key.label) & GII_KM_LOCK) {
 		if (ev->key.type == evKeyPress) {
@@ -351,7 +361,7 @@ handle_modifier(linkbd_priv *priv, gii_event *ev)
 		}
 	}
 	priv->modifiers = priv->lockedmod | priv->normalmod;
-}	
+}
 
 
 static inline gii_event_mask
@@ -387,11 +397,11 @@ GII_keyboard_handle_data(gii_input *inp, int code)
 		ev.key.sym   = priv->keydown_sym[code];
 		ev.key.label = priv->keydown_label[code];
 	} else {
-		/* Temporarily switch back to the old mode because unicodes arent't
-		   available through table lookup in MEDIUMRAW
+		/* Temporarily switch back to the old mode because
+		   unicodes aren't available through table lookup in MEDIUMRAW
 		*/
 		if (ioctl(priv->fd, KDSKBMODE, priv->old_mode) < 0) {
-			GIIDPRINT_MISC("Linux-kbd: ioctl(KDSKBMODE) failed.\n");
+			DPRINT_MISC("Linux-kbd: ioctl(KDSKBMODE) failed.\n");
 			return 0;
 		}
 		/* Look up the keysym without modifiers, which will give us
@@ -400,7 +410,7 @@ GII_keyboard_handle_data(gii_input *inp, int code)
 		entry.kb_table = 0;
 		entry.kb_index = code;
 		if (ioctl(priv->fd, KDGKBENT, &entry) < 0) {
-			GIIDPRINT_MISC("Linux-kbd: ioctl(KDGKBENT) failed.\n");
+			DPRINT_MISC("Linux-kbd: ioctl(KDGKBENT) failed.\n");
 			return 0;
 		}
 		labelval = entry.kb_value;
@@ -419,24 +429,24 @@ GII_keyboard_handle_data(gii_input *inp, int code)
 
 		entry.kb_index = code;
 		if (ioctl(priv->fd, KDGKBENT, &entry) < 0) {
-			GIIDPRINT_MISC("Linux-kbd: ioctl(KDGKBENT) failed.\n");
+			DPRINT_MISC("Linux-kbd: ioctl(KDGKBENT) failed.\n");
 			return 0;
 		}
 
 		/* Switch back to MEDIUMRAW */
 		if (ioctl(priv->fd, KDSKBMODE, K_MEDIUMRAW) < 0) {
-			GIIDPRINT_MISC("Linux-kbd: ioctl(KDSKBMODE) failed.\n");
+			DPRINT_MISC("Linux-kbd: ioctl(KDSKBMODE) failed.\n");
 			return 0;
 		}
 
 		switch (entry.kb_value) {
 
 		case K_HOLE:
-			GIIDPRINT_EVENTS("Linux-kbd: NOSUCHKEY\n");
+			DPRINT_EVENTS("Linux-kbd: NOSUCHKEY\n");
 			break;
 
 		case K_NOSUCHMAP:
-			GIIDPRINT_EVENTS("Linux-kbd: NOSUCHMAP\n");
+			DPRINT_EVENTS("Linux-kbd: NOSUCHMAP\n");
 			entry.kb_value = K_HOLE;
 			break;
 		}
@@ -475,11 +485,11 @@ GII_keyboard_handle_data(gii_input *inp, int code)
 		priv->keydown_label[code]  = ev.key.label;
 	}
 
-	GIIDPRINT_EVENTS("KEY-%s button=0x%02x modifiers=0x%02x "
+	DPRINT_EVENTS("KEY-%s button=0x%02x modifiers=0x%02x "
 		"sym=0x%04x label=0x%04x\n",
-		(ev.key.type == evKeyRelease) ? "UP" : 
+		(ev.key.type == evKeyRelease) ? "UP" :
 		((ev.key.type == evKeyPress) ? "DN" : "RP"),
-		ev.key.button, ev.key.modifiers, 
+		ev.key.button, ev.key.modifiers,
 		ev.key.sym,  ev.key.label);
 
 	if (priv->call_vtswitch) {
@@ -498,15 +508,15 @@ GII_keyboard_handle_data(gii_input *inp, int code)
 		    (KTYP(entry.kb_value) == KT_CONS) && priv->ctrlstate) {
 			int rc;
 			int new_cons = 1+KVAL(entry.kb_value);
-			
+
 			/* Clear the keydown buffer, since we'll never know
 			   what keys the user pressed (or released) while they
 			   were away.
 			 */
-			GIIDPRINT_MISC("Flushing all keys.\n");
+			DPRINT_MISC("Flushing all keys.\n");
 			rc = GII_keyboard_flush_keys(inp);
 
-			GIIDPRINT_MISC("Switching to console %d.\n", new_cons);
+			DPRINT_MISC("Switching to console %d.\n", new_cons);
 
 			if (ioctl(priv->fd, VT_ACTIVATE, new_cons) < 0) {
 				perror("ioctl(VT_ACTIVATE)");
@@ -537,7 +547,7 @@ static gii_event_mask GII_keyboard_poll(gii_input *inp, void *arg)
 	gii_event_mask result = 0;
 	int readlen, i;
 
-	GIIDPRINT_EVENTS("GII_keyboard_poll(%p, %p) called\n", inp, arg);
+	DPRINT_EVENTS("GII_keyboard_poll(%p, %p) called\n", inp, arg);
 
 	if (priv->eof) {
 		/* End-of-file, don't do any polling */
@@ -553,11 +563,11 @@ static gii_event_mask GII_keyboard_poll(gii_input *inp, void *arg)
 	} else {
 		if (! FD_ISSET(priv->fd, ((fd_set*)arg))) {
 			/* Nothing to read on our fd */
-			GIIDPRINT_EVENTS("GII_keyboard_poll: dummypoll\n");
+			DPRINT_EVENTS("GII_keyboard_poll: dummypoll\n");
 			return 0;
 		}
 	}
-	
+
 	/* Read keyboard data */
 	while ((readlen = read(priv->fd, buf, 256)) > 0) {
 		for (i = 0; i < readlen; i++) {
@@ -578,7 +588,7 @@ static gii_event_mask GII_keyboard_poll(gii_input *inp, void *arg)
 		if (errno != EINTR) {
 			priv->eof = 1;
 		}
-		GIIDPRINT_EVENTS("Linux-kbd: EOF occured on fd: %d\n",
+		DPRINT_EVENTS("Linux-kbd: EOF occured on fd: %d\n",
 				 priv->fd);
 	} else if (readlen < 0) {
 		/* Error, we try again next time */
@@ -609,7 +619,7 @@ static void send_devinfo(gii_input *inp)
 	size = sizeof(gii_cmd_nodata_event)+sizeof(gii_cmddata_getdevinfo);
 
 	_giiEventBlank(&ev, size);
-	
+
 	ev.any.size   = size;
 	ev.any.type   = evCommand;
 	ev.any.origin = inp->origin;
@@ -650,7 +660,7 @@ static int GII_lin_kbd_close(gii_input *inp)
 {
 	linkbd_priv *priv = LINKBD_PRIV(inp);
 
-	GIIDPRINT_MISC("Linux-kbd cleanup\n");
+	DPRINT_MISC("Linux-kbd cleanup\n");
 
 	if (priv == NULL) {
 		/* Make sure we're only called once */
@@ -678,23 +688,25 @@ static int GII_lin_kbd_close(gii_input *inp)
 
 	fputc('\n', stderr);
 	fflush(stderr);
-	
-	GIIDPRINT("Linux-kbd: exit OK.\n");
+
+	DPRINT("Linux-kbd: exit OK.\n");
 
 	return 0;
 }
 
 
-int GIIdlinit(gii_input *inp, const char *args, void *argptr)
+EXPORTFUNC int GIIdl_linux_kbd(gii_input *inp, const char *args, void *argptr);
+
+int GIIdl_linux_kbd(gii_input *inp, const char *args, void *argptr)
 {
-	char *filename = "/dev/tty";
-	
-	GIIDPRINT_MISC("linux_kbd starting.(args=\"%s\",argptr=%p)\n",
+	const char *filename = "/dev/tty";
+
+	DPRINT_MISC("linux_kbd starting.(args=\"%s\",argptr=%p)\n",
 		    args, argptr);
 
 	/* Initialize */
 	if (args && *args) {
-		filename = (char *) args;
+		filename = args;
 	}
 
 	if(_giiRegisterDevice(inp,&devinfo,NULL)==0) {
@@ -720,8 +732,8 @@ int GIIdlinit(gii_input *inp, const char *args, void *argptr)
 
 	/* Send initial cmdDevInfo event */
 	send_devinfo(inp);
-	
-	GIIDPRINT_MISC("linux_kbd fully up\n");
+
+	DPRINT_MISC("linux_kbd fully up\n");
 
 	return 0;
 }
