@@ -1,4 +1,4 @@
-/* $Id$
+/* $Id: input.c,v 1.17 2005/08/04 12:43:30 cegger Exp $
 ******************************************************************************
 
    SpaceOrb: input
@@ -36,7 +36,6 @@
 #include "config.h"
 #include <ggi/internal/gii.h>
 #include <ggi/internal/gii_debug.h>
-#include <ggi/internal/gii_target.h>
 
 #include <stdlib.h>
 #include <string.h>
@@ -177,7 +176,7 @@ orb_parse_greeting(gii_input *inp, unsigned char *buf, int len)
 	int actual;
 
 
-	GIIDPRINT_EVENTS("spaceorb greeting packet (len=%d).\n", len);
+	DPRINT_EVENTS("spaceorb greeting packet (len=%d).\n", len);
 
 	/* check for trailing CR */
 
@@ -198,7 +197,7 @@ orb_parse_greeting(gii_input *inp, unsigned char *buf, int len)
 	}
 		 
 	if (actual == len) {
-		GIIDPRINT_EVENTS("spaceorb: short packet\n");
+		DPRINT_EVENTS("spaceorb: short packet\n");
 		return 0;  /* none */
 	}
 	
@@ -208,12 +207,12 @@ orb_parse_greeting(gii_input *inp, unsigned char *buf, int len)
 	buf++;
 
 	for (i=0; i < (actual-1); i++) {
-		name[i] = isprint(buf[i]) ? buf[i] : '.';
+		name[i] = isprint((uint8_t)(buf[i])) ? buf[i] : '.';
 	}
 
 	name[i] = 0;
 
-	GIIDPRINT_MISC("SpaceOrb: Device greeting is `%s'.\n", name);
+	DPRINT_MISC("SpaceOrb: Device greeting is `%s'.\n", name);
 
 	return actual+1;
 }
@@ -227,10 +226,10 @@ orb_parse_buttons(gii_input *inp, unsigned char *buf, int len)
 	int buts;
 	int checksum;
 	
-	GIIDPRINT_EVENTS("spaceorb button packet (len=%d).\n", len);
+	DPRINT_EVENTS("spaceorb button packet (len=%d).\n", len);
 
 	if (len < 5) {
-		GIIDPRINT_EVENTS("spaceorb: short packet\n");
+		DPRINT_EVENTS("spaceorb: short packet\n");
 		return 0;
 	}
 	
@@ -242,7 +241,7 @@ orb_parse_buttons(gii_input *inp, unsigned char *buf, int len)
 
 	orb->buttons = buts;
 
-	GIIDPRINT_EVENTS("spaceorb button packet OK.\n");
+	DPRINT_EVENTS("spaceorb button packet OK.\n");
 
 	return 5;
 }
@@ -261,10 +260,10 @@ orb_parse_motion(gii_input *inp, unsigned char *buf, int len)
 	int i;
 
 
-	GIIDPRINT_EVENTS("spaceorb motion packet (len=%d).\n", len);
+	DPRINT_EVENTS("spaceorb motion packet (len=%d).\n", len);
 
 	if (len < 12) {
-		GIIDPRINT_EVENTS("spaceorb: short packet\n");
+		DPRINT_EVENTS("spaceorb: short packet\n");
 		return 0;
 	}
 	
@@ -303,7 +302,7 @@ orb_parse_motion(gii_input *inp, unsigned char *buf, int len)
 
 	orb_send_axes(inp, axes, orb->axes, DEFAULT_WOBBLE * 64);
 
-	GIIDPRINT_EVENTS("spaceorb motion packet OK.\n");
+	DPRINT_EVENTS("spaceorb motion packet OK.\n");
 
 	return 12;
 }
@@ -326,7 +325,7 @@ static int M_spaceorb(gii_input *inp, unsigned char *buf, int len)
 			break;
 	}
 
-	GIIDPRINT_EVENTS("Invalid spaceorb packet (0x%02x).\n", buf[0]);
+	DPRINT_EVENTS("Invalid spaceorb packet (0x%02x).\n", buf[0]);
 
 	return 1;
 }
@@ -353,7 +352,7 @@ static int do_spaceorb_open(gii_input *inp, char *filename,
 	tcflush(orb->fd, TCIOFLUSH);
 
 	if (tcgetattr(orb->fd, &orb->old_termios) < 0) {
-		GIIDPRINT("tcgetattr failed.\n");
+		DPRINT("tcgetattr failed.\n");
 /*		close(orb->fd);		*/
 /*		return GGI_ENODEVICE;		*/
 	}
@@ -372,7 +371,7 @@ static int do_spaceorb_open(gii_input *inp, char *filename,
 	tio.c_cc[VTIME] = 0;
 
 	if (tcsetattr(orb->fd, TCSANOW, &tio) < 0) {
-		GIIDPRINT("tcsetattr failed.\n");
+		DPRINT("tcsetattr failed.\n");
 /*		close(orb->fd);		*/
 /*		return GGI_ENODEVICE;		*/
 	}
@@ -408,7 +407,7 @@ static int do_spaceorb_open(gii_input *inp, char *filename,
  * "-baud=9600", and that sort of thing...
  */
  
-static char *parse_field(char *dst, int max, char *src)
+static const char *parse_field(char *dst, int max, const char *src)
 {
 	int len=1;   /* includes trailing NUL */
 
@@ -429,7 +428,7 @@ static char *parse_field(char *dst, int max, char *src)
 }
 
 static inline void
-parse_spaceorb_specifier(char *spec, char *_devname, char *options)
+parse_spaceorb_specifier(const char *spec, char *_devname, char *options)
 {
 	*_devname = *options = 0;
 
@@ -448,7 +447,7 @@ static char *parse_opt_int(char *opt, int *val)
 {
 	*val = 0;
 
-	for (; *opt && isdigit((int)*opt); opt++) {
+	for (; *opt && isdigit((uint8_t)*opt); opt++) {
 		*val = ((*val) * 10) + ((*opt) - '0');
 	}
 
@@ -483,7 +482,7 @@ static void parse_options(char *opt, int *baud, int *dtr, int *rts)
 
 
 static inline int
-GII_spaceorb_init(gii_input *inp, char *typname)
+GII_spaceorb_init(gii_input *inp, const char *typname)
 {
 	SpaceOrbHook *orb = SPACEORB_HOOK(inp);
 	char _devname[256];
@@ -519,7 +518,7 @@ static void GII_spaceorb_exit(gii_input *inp)
 	SpaceOrbHook *orb = SPACEORB_HOOK(inp);
 
 	if (tcsetattr(orb->fd, TCSANOW, &orb->old_termios) < 0) {
-		GIIDPRINT("tcsetattr failed.\n");
+		DPRINT("tcsetattr failed.\n");
 	}
 
 	close(orb->fd);
@@ -528,7 +527,7 @@ static void GII_spaceorb_exit(gii_input *inp)
 	free(orb);
 	inp->priv = NULL;
 
-	GIIDPRINT("SpaceOrb: exit OK.\n");
+	DPRINT("SpaceOrb: exit OK.\n");
 }
 
 
@@ -590,12 +589,12 @@ static gii_event_mask GII_spaceorb_poll(gii_input *inp, void *arg)
 	SpaceOrbHook *priv = SPACEORB_HOOK(inp);
 	int doselect = 1;
 
-	GIIDPRINT_EVENTS("GII_spaceorb_poll(%p, %p) called\n", inp, arg);
+	DPRINT_EVENTS("GII_spaceorb_poll(%p, %p) called\n", inp, arg);
 
 	if (arg != NULL) {
 		if (! FD_ISSET(priv->fd, ((fd_set*)arg))) {
 			/* Nothing to read on our fd */
-			GIIDPRINT_EVENTS("GII_spaceorb_poll: dummypoll\n");
+			DPRINT_EVENTS("GII_spaceorb_poll: dummypoll\n");
 			return 0;
 		}
 		doselect = 0;
@@ -700,7 +699,7 @@ static int GII_spaceorb_senddevinfo(gii_input *inp)
 	return _giiEvQueueAdd(inp, &ev);
 }
 
-static int GII_spaceorb_sendvalinfo(gii_input *inp, uint32 val)
+static int GII_spaceorb_sendvalinfo(gii_input *inp, uint32_t val)
 {
 	gii_cmddata_getvalinfo *VI;
 
@@ -742,7 +741,7 @@ static int GII_spaceorb_sendevent(gii_input *inp, gii_event *ev)
 
 	if (ev->cmd.code == GII_CMDCODE_GETVALINFO) {
 	
-		uint32 i;
+		uint32_t i;
 		gii_cmddata_getvalinfo *vi;
 		
 		vi = (gii_cmddata_getvalinfo *) ev->cmd.data;
@@ -766,7 +765,7 @@ static int GII_spaceorb_sendevent(gii_input *inp, gii_event *ev)
 
 static int GII_spaceorb_close(gii_input *inp)
 {
-	GIIDPRINT_MISC("SpaceOrb cleanup\n");
+	DPRINT_MISC("SpaceOrb cleanup\n");
 
 	if (SPACEORB_HOOK(inp)) {
 		GII_spaceorb_exit(inp);
@@ -776,17 +775,19 @@ static int GII_spaceorb_close(gii_input *inp)
 }
 
 
-int GIIdlinit(gii_input *inp, const char *args, void *argptr)
+EXPORTFUNC int GIIdl_spaceorb(gii_input *inp, const char *args, void *argptr);
+
+int GIIdl_spaceorb(gii_input *inp, const char *args, void *argptr)
 {
 	int ret;
-	char *spec = "";
+	const char *spec = "";
 	
-	GIIDPRINT_MISC("SpaceOrb starting.(args=\"%s\",argptr=%p)\n",args,argptr);
+	DPRINT_MISC("SpaceOrb starting.(args=\"%s\",argptr=%p)\n",args,argptr);
 
 	/* Initialize */
 
 	if (args && *args) {
-		spec = (char *) args;
+		spec = args;
 	}
 	
 	if(_giiRegisterDevice(inp,&spaceorb_devinfo,spaceorb_valinfo)==0) {
@@ -816,7 +817,7 @@ int GIIdlinit(gii_input *inp, const char *args, void *argptr)
 	/* Send initial cmdDevInfo event */
 	GII_spaceorb_senddevinfo(inp);
 	
-	GIIDPRINT_MISC("SpaceOrb fully up\n");
+	DPRINT_MISC("SpaceOrb fully up\n");
 
 	return 0;
 }
