@@ -1,4 +1,4 @@
-/* $Id$
+/* $Id: common.c,v 1.7 2004/11/27 14:37:54 soyt Exp $
 ******************************************************************************
 
    Input-touchscreen_common: common functions for touchscreen handling
@@ -81,11 +81,11 @@ int touchscreen_init(void)
       else if(values==7)
 	  configured = 1;
       fclose(fp);
-      GIIDPRINT_MISC("touchscreen: %d %d %d | %d %d %d (%dx%d)\n",
+      DPRINT_MISC("touchscreen: %d %d %d | %d %d %d (%dx%d)\n",
 		     tc.a, tc.b, tc.c, tc.d, tc.e, tc.e, calwidth, calheight);
     }
   if (!configured)
-    GIIDPRINT_MISC("touchscreen: NOT configured! Calibrate before use.\n");
+    DPRINT_MISC("touchscreen: NOT configured! Calibrate before use.\n");
 
   return configured;
 }
@@ -97,7 +97,7 @@ int touchscreen_sendvalinfo(gii_input *inp, int val)
   gii_cmddata_getvalinfo *VI;
   gii_event ev;
 
-  GIIDPRINT_MISC("touchscreen sending valinfo\n");
+  DPRINT_MISC("touchscreen sending valinfo\n");
     
   if (val >= 2) return GGI_ENOSPACE;
 
@@ -126,7 +126,7 @@ int touchscreen_senddevinfo(gii_input * inp)
   
   int size = sizeof(gii_cmd_nodata_event)+sizeof(gii_cmddata_getdevinfo);
   
-  GIIDPRINT_MISC("touchscreen sending devinfo\n");
+  DPRINT_MISC("touchscreen sending devinfo\n");
   
   _giiEventBlank(&ev, size);
   
@@ -325,13 +325,13 @@ gii_event_mask touchscreen_handledata(gii_input *inp,
 
   if (touchscreen_filter(&x, &y, pressure))
     {
-      GIIDPRINT_EVENTS("touchscreen: filtered out!\n");
+      DPRINT_EVENTS("touchscreen: filtered out!\n");
       return sent;
     }
 
   if(inp->curreventmask & emValuator)
     {
-      GIIDPRINT_EVENTS("touchscreen: valuator (%d,%d)\n", x, y);
+      DPRINT_EVENTS("touchscreen: valuator (%d,%d)\n", x, y);
       
       _giiEventBlank(&ev, sizeof(gii_val_event));
       ev.any.type   = evValAbsolute;
@@ -352,7 +352,7 @@ gii_event_mask touchscreen_handledata(gii_input *inp,
       is_calibrated)
     {
       touchscreen_pentoscreen(&x, &y);
-      GIIDPRINT_EVENTS("touchscreen: pmove event (%d,%d)\n", x, y);
+      DPRINT_EVENTS("touchscreen: pmove event (%d,%d)\n", x, y);
 
       _giiEventBlank(&ev, sizeof(gii_pmove_event));
       
@@ -375,7 +375,7 @@ gii_event_mask touchscreen_handledata(gii_input *inp,
       if ((inp->curreventmask & emPtrButtonPress) &&
 	  pressure && !tshook->is_pressed)
 	{
-	  GIIDPRINT_EVENTS("touchscreen: pbutton pressed event\n");
+	  DPRINT_EVENTS("touchscreen: pbutton pressed event\n");
 
 	  /* touches surface */
 	  ev.pbutton.type = evPtrButtonPress;
@@ -385,7 +385,7 @@ gii_event_mask touchscreen_handledata(gii_input *inp,
       else if ((inp->curreventmask & emPtrButtonRelease) && 
 	       !pressure && tshook->is_pressed)
 	{
-	  GIIDPRINT_EVENTS("touchscreen: pbutton release event\n");
+	  DPRINT_EVENTS("touchscreen: pbutton release event\n");
 
 	  /* pen leaves surface */
 	  ev.pbutton.type = evPtrButtonRelease;
